#######################################################################
# PCA.R
#
# This script runs through an example ordination using PCA and points out some basics for 
# first time users in RStudio.
#
# Depends on: devtools
#             ggbiplot
#
# created 11/28/2013 by Thiago G. Martins
#
# last modified: 7/2/2014
#            by: A. Michelle Lawing
#
# This code demonstrates how to apply and visualize PCA in R, specifically using RStudio. 
# There are many packages and functions that can apply PCA in R. In this exercise we will 
# use function prcomp from the stats package. We will also visualize PCA in R using Base R 
# graphics. However, the recommended visualization function for PCA is ggbiplot, which is 
# implemented by Vince Q. Vu and available on github.
#
#######################################################################

#set working dir

data(iris) # load data
head(iris) # have a look

log.ir <- log(iris[, 1:4]) # log transform 
ir.species <- iris[, 5] # put species in their own variable

# apply PCA - scale. = TRUE is highly 
# advisable, but default is FALSE. 
ir.pca <- prcomp(log.ir, center = TRUE, scale. = TRUE) 

# print method
print(ir.pca)

# plot method
plot(ir.pca, type = "l")

# summary method
summary(ir.pca)

# Predict PCs
predict(ir.pca, newdata = tail(log.ir, 2))

# plot results
biplot(ir.pca)

# see the first six rows of PC scores
head(ir.pca$x)

# vector of colors
# make a new variable with the same length as ir.species
ir.color <- array(NA, dim = length(ir.species)) 
# set all of the same species values equal to a color
ir.color[ir.species == unique(ir.species)[1]] <- "orange" 
ir.color[ir.species == unique(ir.species)[2]] <- "red" 
ir.color[ir.species == unique(ir.species)[3]] <- "blue" 

# plot PC1 and PC2
plot(ir.pca$x[, 1:2], pch = 16, col = ir.color)
# add a legend
legend("topleft", legend = unique(ir.species), col = unique(ir.color), 
       pch = 16)

# plot PC1 and PC2
plot(ir.pca$x[, 1:2], pch = 16, col = ir.color)

# add a legend
legend("topleft", legend = unique(ir.species), col = unique(ir.color), pch = 16)

# rotate data  
rot <- ir.pca$rotation
arrows(0, 0, 2 * rot[1, 1], 2 * rot[2, 1], lwd = 4)
arrows(0, 0, 2 * rot[1, 2], 2 * rot[2, 2], lwd = 4)
arrows(0, 0, 2 * rot[3, 1], 2 * rot[3, 2], lwd = 4)
arrows(0, 0, 2 * rot[4, 1], 2 * rot[4, 2], lwd = 4)  

# add text
text(2 * rot[1, 1] + 0.15, 2 * rot[2, 1] - 0.25, rownames(rot)[1], pos = 1, cex = 1)
text(2 * rot[1, 2], 2 * rot[2, 2] - 0.15, rownames(rot)[2], pos = 4, cex = 1)
text(2 * rot[3, 1] + 0.15, 2 * rot[3, 2] - 0.25, rownames(rot)[3], pos = 4, cex = 1)
text(2 * rot[4, 1] + 0.15, 2 * rot[4, 2] + 0.25, rownames(rot)[4], pos = 4, cex = 1)

# install devtools and load library using the packages tab

# install ggbiplot from github
install_github("ggbiplot", "vqv")

# load library ggbiplot from the packages tab  

# make plot
g <- ggbiplot(ir.pca, obs.scale = 1, var.scale = 1, 
              groups = ir.species, ellipse = TRUE, 
              circle = TRUE)
g <- g + scale_color_discrete(name = '')
g <- g + theme(legend.direction = 'horizontal', 
               legend.position = 'top')
print(g)