# AN INTRODUCTION TO PLOTTING WITH BASE GRAPHICS AND LATTICE GRAPHICS

# We will use two of the data sets that come with R, one for death rates in Virginia, and one for measurements of different characteristics of three species of iris.

# Load the data:
data(iris)
data(VADeaths)
# Examine it:
head(VADeaths)

################################################
# 1.B. BASE PLOTS: HIGH-LEVEL PLOTTING COMMANDS.

# 1.B.a BARPLOT
barplot(VADeaths, beside=TRUE, legend=TRUE, ylim=c(0,90), ylab="Deaths per 1000", main="Death rates in Virginia")
# Try pulling out all of the supplemental elements to figure out what each does:
barplot(VADeaths)
# For example, beside=TRUE causes values in each column to be plotted side-by-side; legend=TRUE added upper-right legend.


# 1.B.b DOTCHART
dotchart(VADeaths, xlim=c(0, 75), xlab="Deaths per 1000", main="Death Rates in Virginia")


# 1.B.c PIE CHART
groupsizes <- c(18, 30, 32, 10, 10)
labels <- c("A", "B", "C", "D", "F")
pie(groupsizes, labels, col=c("grey40", "white", "grey", "black", "grey90"))
# Note that pie charts have fallen out of favor with statisticians.  Why?


# 1.B.d HISTOGRAMS
x <- rnorm(100)
hist(x)
# There are multiple options for specifying the breaks if the default breaks don't seem right.  Look at ?hist as a starting point.


# 1.B.e BOX PLOTS
# Elements include: Outliers - whiskers (1.5*IQR) - quartiles (median of each half) - median
# ~50% of data will lie within the box
boxplot(Sepal.Length~Species, data=iris, ylab="Sepal length (cm)", main="Iris measurements", boxwex=0.5)


# 1.B.f PLOT
# A more generic function, plot()
# Note that the "type" argument can specify what you want; you can use type="n" to draw a blank frame, and then use other functions to draw inside the plot.

x <- rnorm(100)
y <- rpois(100, 30) # assigns 100 random Poisson observations to y with a mean value of 30

plot(x, y, main="Poisson versus Normal")
plot(x, y, type="l") # Connects points in order; looks like a tangle
plot(sort(x), sort(y), type="l") # A plot of sample "quantiles"

# Check out ?plot and ?par for many more optional arguments.

# 1.B.g QQPLOTS
# Compare distributions of two groups, or compare a sample with a reference distribution.
# For two groups of equal size, observations are sorted and plotted as a scatterplot (as above)
# If groups are different sizes, a scheme is used to artificially match them.
# For plotting a single sample against a reference distribution: theoretical quantiles are used for the X axis.

# Examples:
X <- rnorm(1000)
A <- rnorm(1000)
qqplot(X, A, main="A and X are the same")
B <- rnorm(1000, mean=3, sd=2)
qqplot(X, B, main="B is rescaled to X")
C <- rt(1000, df=2)
qqplot(X, C, main="C has heavier tails")
D <-exp(rnorm(1000))
qqplot(X, D, main="D is skewed to the right")

###############################################
# 1.C. ANNOTATING PLOTS WITH LOW-LEVEL FUNCTIONS

# Annotating a plot - example
plot(iris$Sepal.Length, iris$Sepal.Width, main="Sepal")

# Now, let's say you wish to overplot the longest sepal lengths in a different color.  
# First, find the longest sepal lengths:
tapply(iris$Sepal.Length, iris$Species, which.max)

# Note that tapply() subsets the data frame and then runs the function. It took some extra work to figure out the appropriate rows in the original data frame. I'm skipping the in-between steps here for the sake of continuing the example:

with(iris[c(15,51,132),], points(Sepal.Length, Sepal.Width, pch=16))

# Even more fancy: setting all the point shapes at once, and adding other elements to the plot:

with(iris, plot(Sepal.Length, Sepal.Width, pch=as.integer(Species)))
# Add 3 lines, one for each species:
abline(lm(Sepal.Width~Sepal.Length, data=subset(iris, iris$Species=="setosa")), lty=1)
abline(lm(Sepal.Width~Sepal.Length, data=subset(iris, iris$Species=="versicolor")), lty=2)
abline(lm(Sepal.Width~Sepal.Length, data=subset(iris, iris$Species=="virginica")), lty=3)
# Add a legend:
legend("topright", legend=c("setosa", "versicolor", "virginica"), lty=1:3)


# You can do things with the margins, too:
par(mar=c(5, 5, 5, 5), + 0.1)
plot(c(1,9), c(0,50), type="n", xlab="", ylab="")
text(6, 40, "Plot region")
points(6, 20)
text(6, 20, "(6, 20)", adj=c(0.5, 2))
mtext(paste("Margin", 1:4), side=1:4, line=3)
mtext(paste("Line", 0:4), side=1, line=0:4, at=3, cex=0.6)
mtext(paste("Line", 0:4), side=2, line=0:4, at=15, cex=0.6)
mtext(paste("Line", 0:4), side=3, line=0:4, at=3, cex=0.6)
mtext(paste("Line", 0:4), side=4, line=0:4, at=15, cex=0.6)


###############################################
# 1.D. SETTING AND CHECKING PARAMETERS
quartz() # Open a plotting device (plotting window)
par("mfrow")
par(mfrow=c(1,2))
par(list(mfrow=c(2,2), mar=c(5, 5, 5, 5)))
par("mar")


###############################################
###############################################
#-------------Getting fancy with LATTICE GRAPHICS-----------------#
###############################################
###############################################
# To install new packages, use:
install.packages("lattice")

# To load the package for this exercise, use:
library(lattice)
# I generally load all the packages at the beginning of a script.

xyplot(Sepal.Length~Sepal.Width, data=iris) # Note the ~tildae~ used for formulas of the form y=x

# This looks pretty good, but wait, there's more. Lattice functions produce an *object* of class "trellis," which contains a description of the plot. The print() method for objects of this class does the actual drawing.  Observe:
splot <- xyplot(Sepal.Length~Sepal.Width, data=iris)
class(splot)
print(splot)

# Doing this makes it possible to update() the trellis object
update(splot, main="Sepal characteristics for three iris species")
print(splot)
# So why does it look the same? You have to *assign* the value returned by the update() function:
splot2 <- update(splot, main="Sepal characteristics for three iris species")
print(splot2)

# Now, the real power: Playing around with some formula options:
xyplot(Sepal.Length~Sepal.Width + Species, data=iris)

xyplot(Sepal.Length+Sepal.Width~Species, data=iris)

wireframe(Sepal.Width~Sepal.Length+Petal.Width, data=iris)
# This is not the best example use of a wireframe plot; it would work better with an x, y, z surface, but hopefully you get the idea.

xyplot(Sepal.Length~Sepal.Width|Species, data=iris) # The "|" is used to specify a conditioning variable; there can be more than one conditioning variable, and the conditioning variable can be numeric.  Use the shingle() function to explicitly control the ranges, or use the equal.count() function to generate ranges automagically given a number of groups.

xyplot(Sepal.Length~Sepal.Width|Petal.Width, data=iris)

# More complex example:
pwidths <- equal.count(iris$Petal.Width, number=4, overlap=0)

xyplot(Sepal.Length~Sepal.Width|pwidths, data=iris, main="Iris sepal and petal characteristics", xlab="Sepal Width", ylab="Sepal Length", par.strip.text=list(cex=0.8), par.settings=list(axis.text=list(cex=0.4), fontsize=list(text=14, points=10)))
# Notice how there is lots of fine control over details.

show.settings()
trellis.par.get("fontsize")
# Set settings globally with trellis.par.set():
trellis.par.set(list(fontsize=list(text=14, points=10)))
# Set them within a plot with par.settings - see example above.

# Arranging panels within a plot:
xyplot(Sepal.Length~Sepal.Width|pwidths, data=iris, layout=c(4,1), aspect=1, index.cond=list(4:1)) 

# The last argument specifies the order of the panels.
# aspect options to try: "fill", "xy", 1

# Arranging multiple plots on a page: make trellis objects for each plot, then use print() to specify positions:
sepalp <- xyplot(Sepal.Length~Sepal.Width|Species, data=iris)
petalp <- xyplot(Petal.Length~Petal.Width|Species, data=iris)

print(sepalp, position=c(0,0.2,1,1), more=TRUE)
print(petalp, position=c(0, 0, 1, 0.33))
## FIX THIS!!

# This is really just the beginning.  As mentioned earlier in this lesson, I recommend Paul Murrell's book _R Graphics_ as a resource to learn more, and as you determine your specific interests you will probably be able to track down further resources.  You may also want to look at _Lattice: Multivariate Data Visualization with R_, by Deepayan Sarkar, the author of the lattic package.